# McCole

A template for building simple static websites.

1.  `pip install mccole` to install.
2.  `mccole install .` to copy the following tools into the current directory:
    -   `bin/lint.py`: internal project check
    -   `bin/render.py`: Markdown-to-HTML translator
    -   `static/page.css`: styling for regular pages
    -   `static/slides.css`: styling for slides
    -   `static/slides.js`: JavaScript to make slides interactive
    -   `templates/page.html`: Jinja template for pages
    -   `templates/slides.html`: Jinja template for slides
